@@ -18,7 +18,7 @@ class MiniECS:
         response = (False, "None")
         try:
             command = 'X!STOP'
-            message = name.encode()
+            message = command.encode()
             print('sending {!r}'.format(message))
             self.sock.sendall(message)
 
